@@ -1,7 +1,7 @@
 /*
  * UFC-crypt: ultra fast crypt(3) implementation
  *
- * Copyright (C) 1991, 1992, 1993, 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1991, 1992, 1993, 1996, 1997 Free Software Foundation, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -344,7 +344,7 @@ _ufc_copymem(from, to, cnt)
  */
 
 void
-init_des_r(__data)
+__init_des_r(__data)
      struct crypt_data *__data;
 {
   int comes_from_bit;
@@ -543,9 +543,9 @@ small_tables_done:
 }
 
 void
-init_des()
+__init_des()
 {
-  init_des_r(&_ufc_foobar);
+  __init_des_r(&_ufc_foobar);
 }
 
 /*
@@ -597,7 +597,7 @@ _ufc_setup_salt_r(s, __data)
   ufc_long i, j, saltbits;
 
   if(__data->initialized == 0)
-    init_des_r(__data);
+    __init_des_r(__data);
 
   if(s[0] == __data->current_salt[0] && s[1] == __data->current_salt[1])
     return;
@@ -777,7 +777,7 @@ _ufc_output_conversion_r(v1, v2, salt, __data)
  */
 
 void
-encrypt_r(__block, __edflag, __data)
+__encrypt_r(__block, __edflag, __data)
      char *__block;
      int __edflag;
      struct crypt_data *__data;
@@ -870,13 +870,14 @@ encrypt_r(__block, __edflag, __data)
     *__block++ = (r1 & longmask[i]) != 0;
   }
 }
+weak_alias (__encrypt_r, encrypt_r)
 
 void
 encrypt(__block, __edflag)
      char *__block;
      int __edflag;
 {
-  encrypt_r(__block, __edflag, &_ufc_foobar);
+  __encrypt_r(__block, __edflag, &_ufc_foobar);
 }
 
 
@@ -885,7 +886,8 @@ encrypt(__block, __edflag)
  * key and setup the machinery.
  */
 
-void setkey_r(__key, __data)
+void
+__setkey_r(__key, __data)
      __const char *__key;
      struct crypt_data *__data;
 {
@@ -902,10 +904,11 @@ void setkey_r(__key, __data)
   }
   _ufc_mk_keytab_r(ktab, __data);
 }
+weak_alias (__setkey_r, setkey_r)
 
 void
 setkey(__key)
      __const char *__key;
 {
-  setkey_r(__key, &_ufc_foobar);
+  __setkey_r(__key, &_ufc_foobar);
 }
